#include <EditConstants.au3>
#include <GUIConstantsEx.au3>
#include <StaticConstants.au3>

#cs
	==============================================================================================================

	Name:			Text Effects Designer
	Version:    	0.96
	Author(s):		peethebee (peter_opali@gmx.de) and gafrost
	AutoIt version:	3.1.1.65 (Beta) or later
	Function:		GUI to chosse, test and generate your effect from my text effects UDF (v1.8 included)
	License:		of course freeware, because the wonderfull AutoIt is freeware too
	Sources:		AutoIt standard funcs and included UDFs
	Download:		peethebee's fileman on "http://www.autoitscript.com/fileman/users/peethebee/"

	===============================================================================================================
#ce


#include <GUIConstants.au3>
#include <Array.au3>
#include <File.au3>
#include <Misc.au3>
#include "../text_effects.au3"


; === Copy "text_effects.au3" into include directory ===
Dim $szdrive, $szdir, $szfname, $szext
_PathSplit (@AutoItExe, $szdrive, $szdir, $szfname, $szext)
$dest = $szdrive & $szdir & "\Include\text_effects.au3"
FileCopy("../text_effects.au3", $dest, 1)


; === Setup funcs and params ===
$funcs = StringSplit(StringReplace("About Messages, Airport, Blink, Broad, Color Sequence, Color to color, Enlarge from left, Enlarge from right, Mix up chars, Move cap char through text, Move small char through text, Move in from left, Move in from right, Move out to left, Move out to right, Move string through text, Raining, Rainbow, Scroll through options, Show text behind char, Small, Spin, Spotlight, Style, Uncover from wall to wall, Wave, Zoom", ", ", ","), ",")

Dim $sOutType = "ClipBoard"

If $CMDLINE[0] = 1 Then
	If $CMDLINE[1] = "/StdOut" Then
		$sOutType = "Console"
	EndIf
EndIf

Global $param_input[13], $param_label[13], $param_name[13], $param_is_opt[13]

; === Setup sample arrays for preview ===
Dim $credits[3], $times[3], $start[3], $start_times[3], $options[6], $parts[2]
$credits[0] = "Coder:  p e e t h e b e e ,  2005"
$credits[1] = "Thanks to: J. Bennett and team, the forum members..."
$credits[2] = "and to YOU, if you post your experiences in forum"
$start[0] = "peethebee Entertainment presents"
$start[1] = "an AutoIt UDF show"
$start[2] = '"T e x t  E f f e c t s   1 . 9"'
$start_times[0] = 1500
$start_times[1] = 1250
$start_times[2] = 2500
$times[0] = 2500
$times[1] = 1500
$times[2] = 1000
$options[0] = "Option 1"
$options[1] = "Option 2"
$options[2] = "Option 3"
$options[3] = "Option 4"
$options[4] = "Option 5"
$options[5] = "Option 6"
$parts[0] = 4
$parts[1] = 10


; === Create GUI ===
$gui = GUICreate("Text Effects Designer 0.95 - by peethebee", 750, 550)

GUICtrlCreateGroup("Select effect", 25, 150, 300, 100)
$funcs_combo_str = ""
For $i = 1 To UBound($funcs) - 1
	$funcs_combo_str = $funcs_combo_str & "|" & $funcs[$i]
Next
$funcs_combo_str = StringTrimLeft($funcs_combo_str, 1)
$funcs_combo = GUICtrlCreateCombo("", 50, 190, 250, 100)
GUICtrlSetData(-1, $funcs_combo_str, $funcs[1])
GUICtrlCreateGroup("", -99, -99, 1, 1)

;~ GUICtrlCreateGroup("Preview", 25, 25, 700, 100)
$preview_label = GUICtrlCreateLabel("Preview in Label", 50, 55, 650, 20, $SS_SUNKEN)
GUICtrlSetFont(-1, -1, -1, -1, "Courier New")
$preview_input = GUICtrlCreateInput("Preview in Input", 50, 80, 650, 20)
GUICtrlSetFont(-1, -1, -1, -1, "Courier New")
;~ GUICtrlCreateGroup("", -99, -99, 1, 1)

GUICtrlCreateGroup("Define parameters", 350, 150, 375, 340)

GUICtrlCreateLabel("winhandle", 375, 185, 170, 20)
$input_winhandle = GUICtrlCreateInput("", 550, 180, 150, 20)
GUICtrlSetTip($input_winhandle, "the handle of the target window")
GUICtrlCreateLabel("control_id", 375, 210, 170, 20)
$input_control_id = GUICtrlCreateInput("", 550, 205, 150, 20)
GUICtrlSetTip($input_control_id, "the control ID of the target window")
$lbl_texts = GUICtrlCreateLabel("texts", 375, 235, 170, 20)
GUICtrlSetState($lbl_texts, $GUI_HIDE)
$input_texts = GUICtrlCreateInput("", 550, 230, 150, 20)
GUICtrlSetTip($input_texts, "array containing all texts to show")
GUICtrlSetState($input_texts, $GUI_HIDE)
$lbl_delay = GUICtrlCreateLabel("delay", 375, 260, 170, 20)
$input_delay = GUICtrlCreateInput(50, 550, 255, 150, 20, $ES_NUMBER)
GUICtrlSetTip($input_delay, "delay between two animation steps (in ms) -> 1 = fast - 1000 - slow" & @LF & "time to wait between two animation steps (in ms)")

;about, Mix up chars, Move cap char through text, Move in from right, Move out to right
;Raining, Rainbow, Spin, Spotlight, Style, Uncover from wall to wall, Wave, Zoom
$lbl_showtime = GUICtrlCreateLabel("showtime", 375, 285, 170, 20)
$input_showtime = GUICtrlCreateInput(2000, 550, 280, 150, 20, $ES_NUMBER)
GUICtrlSetTip($input_showtime, "time to show a text (in ms) - it is possible to give an array with the values")

;blink, Zoom
$lbl_hide_delay = GUICtrlCreateLabel("hide_delay", 375, 285, 170, 20)
GUICtrlSetState($lbl_hide_delay, $GUI_HIDE)
$input_hide_delay = GUICtrlCreateInput(50, 550, 280, 150, 20, $ES_NUMBER)
GUICtrlSetTip($input_hide_delay, "time to hide the text")
GUICtrlSetState($input_hide_delay, $GUI_HIDE)

;airport, broad, Color Sequence, Color to color, Move string through text
;Show text behind char, Small, Spotlight
$lbl_start_char = GUICtrlCreateLabel("start_char", 375, 285, 170, 20)
GUICtrlSetState($lbl_start_char, $GUI_HIDE)
$input_start_char = GUICtrlCreateInput("A", 550, 280, 150, 20)
GUICtrlSetTip($input_start_char, "char to start to scroll with (ASCII order)")
GUICtrlSetState($input_start_char, $GUI_HIDE)

;about, Color to color, Spin, Zoom
$lbl_pause = GUICtrlCreateLabel("pause", 375, 310, 170, 20)
$input_pause = GUICtrlCreateInput(750, 550, 305, 150, 20, $ES_NUMBER)
GUICtrlSetTip($input_pause, "time to wait between to texts to show (in ms)")

;airport, Spotlight
$lbl_skip_chars = GUICtrlCreateLabel("skip_chars", 375, 310, 170, 20)
GUICtrlSetState($lbl_skip_chars, $GUI_HIDE)
$input_skip_chars = GUICtrlCreateInput(1, 550, 305, 150, 20, $ES_NUMBER)
GUICtrlSetTip($input_skip_chars, "chars to skip in every step")
GUICtrlSetState($input_skip_chars, $GUI_HIDE)

;Spotlight
$lbl_highlighting_end_char = GUICtrlCreateLabel("skip_chars", 375, 310, 170, 20)
GUICtrlSetState($lbl_highlighting_end_char, $GUI_HIDE)
$input_highlighting_end_char = GUICtrlCreateInput(1, 550, 305, 150, 20)
GUICtrlSetTip($input_highlighting_end_char, "chars to skip in every step")
GUICtrlSetState($input_highlighting_end_char, $GUI_HIDE)
GUICtrlSetTip($input_highlighting_end_char, 'char at the end of the highlighting')

;about, blink, broad, Enlarge from left, Enlarge from right, Mix up chars,
;Move cap char through text, Move string through text, Raining, Rainbow, Spotlight
;Style, Wave
$lbl_type = GUICtrlCreateLabel("type", 375, 335, 170, 20)
$combo_type = GUICtrlCreateCombo("right_to_left", 550, 330, 150, 100)
GUICtrlSetData($combo_type, "blink|enlarge_from_left|enlarge_from_right|fade|left_to_left|left_to_right|mix_up|move_cap_char|move_small_char|rainbow|raining|right_to_right|spotlight|wall_to_wall|wave|zoom_big_to_small|zoom_small_to_big", "zoom_big_to_small")

;Zoom
$lbl_step = GUICtrlCreateLabel("step", 375, 335, 170, 20)
GUICtrlSetState($lbl_step, $GUI_HIDE)
$input_step = GUICtrlCreateInput(1, 550, 330, 150, 20, $ES_NUMBER)
GUICtrlSetTip($input_step, 'step width while down- or upsizing the font size')
GUICtrlSetState($input_step, $GUI_HIDE)

;blink
$lbl_advanced = GUICtrlCreateLabel("advanced", 375, 360, 170, 20)
GUICtrlSetState($lbl_advanced, $GUI_HIDE)
$input_advanced = GUICtrlCreateInput("", 550, 355, 150, 20)
GUICtrlSetTip($input_advanced, 'at "all" none - at "periodic" step - at "parts" array containing cutting positions or positions in format "1.4.9"')
GUICtrlSetState($input_advanced, $GUI_HIDE)

;Move cap char through text, Move small char through text, Spotlight, Style, Wave
$lbl_convert_to_small = GUICtrlCreateLabel("convert_to_small", 375, 360, 170, 20)
GUICtrlSetState($lbl_convert_to_small, $GUI_HIDE)
$combo_convert_to_small = GUICtrlCreateCombo("", 550, 355, 150, 100)
GUICtrlSetData($combo_convert_to_small, "0|1", "0")
GUICtrlSetState($combo_convert_to_small, $GUI_HIDE)

;blink, broad
$lbl_repetitions = GUICtrlCreateLabel("repetitions", 375, 385, 170, 20)
GUICtrlSetState($lbl_repetitions, $GUI_HIDE)
$input_repetitions = GUICtrlCreateInput(1, 550, 380, 150, 20, $ES_NUMBER)
GUICtrlSetTip($input_repetitions, 'number of repetitions of the effect')
GUICtrlSetState($input_repetitions, $GUI_HIDE)

;Style, Zoom
$lbl_font = GUICtrlCreateLabel("Font", 375, 385, 50, 20)
GUICtrlSetState($lbl_font, $GUI_HIDE)
$input_font = GUICtrlCreateInput("Courier New", 550, 380, 150, 20, $ES_READONLY)
GUICtrlSetTip($input_font, "Font to use for the effect")
GUICtrlSetState($input_font, $GUI_HIDE)
$btn_font = GUICtrlCreateButton("Font", 450, 380, 90, 20)
GUICtrlSetState($btn_font, $GUI_HIDE)
GUICtrlSetTip($btn_font, "Select Font to use for the effect")
GUICtrlSetState($btn_font, $GUI_DISABLE)

;Zoom
$lbl_remove = GUICtrlCreateLabel("convert_to_small", 375, 410, 170, 20)
GUICtrlSetState($lbl_remove, $GUI_HIDE)
$combo_remove = GUICtrlCreateCombo("", 550, 405, 150, 100)
GUICtrlSetData($combo_remove, "0|1", "0")
GUICtrlSetState($combo_remove, $GUI_HIDE)

GUICtrlCreateGroup("", -99, -99, 1, 1)

; temp graphic to fill out the GUI *g*
$image = GUICtrlCreatePic(@ScriptDir & "\pic.jpg", 25, 275, 0, 0)

; buttons
$preview_button = GUICtrlCreateButton("&Preview", 335, 510, 140)
$copy_code_button = GUICtrlCreateButton("C&opy code", 487, 510, 140)
$close_button = GUICtrlCreateButton("&Close", 637, 510, 90)

GUISetState(@SW_SHOW)

While 1
	$msg = GUIGetMsg()

	Select
		Case $msg = $gui_event_close Or $msg = $close_button
			Exit
		Case $msg = $btn_font
			$a_font = _ChooseFont ()
			If (Not @error) Then
				GUICtrlSetData($input_font, $a_font[2])
			EndIf
		Case $msg = $funcs_combo
			_ShowParams(GUICtrlRead($funcs_combo))
		Case $msg = $preview_button
			_Preview(GUICtrlRead($funcs_combo))
		Case $msg = $copy_code_button
			_SendCode($sOutType, _BuildFunction(GUICtrlRead($funcs_combo)))
			;Exit
	EndSelect
WEnd

Func _ShowParams($s_combo)
	GUICtrlSetState($lbl_texts, $GUI_HIDE)
	GUICtrlSetState($input_texts, $GUI_HIDE)
	GUICtrlSetState($lbl_start_char, $GUI_HIDE)
	GUICtrlSetState($input_start_char, $GUI_HIDE)
	GUICtrlSetState($lbl_skip_chars, $GUI_HIDE)
	GUICtrlSetState($input_skip_chars, $GUI_HIDE)
	GUICtrlSetState($lbl_hide_delay, $GUI_HIDE)
	GUICtrlSetState($input_hide_delay, $GUI_HIDE)
	GUICtrlSetState($lbl_advanced, $GUI_HIDE)
	GUICtrlSetState($input_advanced, $GUI_HIDE)
	GUICtrlSetState($lbl_repetitions, $GUI_HIDE)
	GUICtrlSetState($input_repetitions, $GUI_HIDE)
	GUICtrlSetState($lbl_showtime, $GUI_HIDE)
	GUICtrlSetState($input_showtime, $GUI_HIDE)
	GUICtrlSetState($lbl_pause, $GUI_HIDE)
	GUICtrlSetState($input_pause, $GUI_HIDE)
	GUICtrlSetState($lbl_type, $GUI_HIDE)
	GUICtrlSetState($combo_type, $GUI_HIDE)
	GUICtrlSetState($lbl_hide_delay, $GUI_HIDE)
	GUICtrlSetState($input_hide_delay, $GUI_HIDE)
	GUICtrlSetState($lbl_convert_to_small, $GUI_HIDE)
	GUICtrlSetState($combo_convert_to_small, $GUI_HIDE)
	GUICtrlSetState($lbl_highlighting_end_char, $GUI_HIDE)
	GUICtrlSetState($input_highlighting_end_char, $GUI_HIDE)
	GUICtrlSetState($lbl_font, $GUI_HIDE)
	GUICtrlSetState($input_font, $GUI_HIDE)
	GUICtrlSetState($btn_font, $GUI_HIDE)
	GUICtrlSetState($btn_font, $GUI_DISABLE)
	GUICtrlSetState($lbl_remove, $GUI_HIDE)
	GUICtrlSetState($combo_remove, $GUI_HIDE)
	GUICtrlSetState($lbl_step, $GUI_HIDE)
	GUICtrlSetState($input_step, $GUI_HIDE)

	Select
		Case $s_combo = "About Messages"

			GUICtrlSetState($lbl_texts, $GUI_SHOW)
			GUICtrlSetState($input_texts, $GUI_SHOW)
			GUICtrlSetData($lbl_showtime, "showtime")
			GUICtrlSetState($lbl_showtime, $GUI_SHOW)
			GUICtrlSetData($input_showtime, 2000)
			GUICtrlSetState($input_showtime, $GUI_SHOW)
			GUICtrlSetTip($input_showtime, "time to show a text (in ms) - it is possible to give an array with the values")
			GUICtrlSetData($lbl_pause, "pause")
			GUICtrlSetState($lbl_pause, $GUI_SHOW)
			GUICtrlSetData($input_pause, 750)
			GUICtrlSetState($input_pause, $GUI_SHOW)
			GUICtrlSetTip($input_pause, "time to wait between to texts to show (in ms)")
			GUICtrlSetData($lbl_type, "type")
			GUICtrlSetData($combo_type, "")
			GUICtrlSetData($combo_type, "right_to_left|blink|enlarge_from_left|enlarge_from_right|fade|left_to_left|left_to_right|mix_up|move_cap_char|move_small_char|rainbow|raining|right_to_right|spotlight|wall_to_wall|wave|zoom_big_to_small|zoom_small_to_big", "zoom_big_to_small")
			GUICtrlSetState($lbl_type, $GUI_SHOW)
			GUICtrlSetState($combo_type, $GUI_SHOW)
			GUICtrlSetData($lbl_delay, "delay")
			GUICtrlSetData($input_delay, 50)
			GUICtrlSetTip($input_delay, "delay between two animation steps (in ms) -> 1 = fast - 1000 - slow" & @LF & "time to wait between two animation steps (in ms)")
			GUICtrlSetState($lbl_delay, $GUI_SHOW)
			GUICtrlSetState($input_delay, $GUI_SHOW)

		Case $s_combo = "Airport"

			GUICtrlSetState($lbl_texts, $GUI_SHOW)
			GUICtrlSetState($input_texts, $GUI_SHOW)
			GUICtrlSetData($lbl_start_char, "start_char")
			GUICtrlSetState($lbl_start_char, $GUI_SHOW)
			GUICtrlSetData($input_start_char, "A")
			GUICtrlSetState($input_start_char, $GUI_SHOW)
			GUICtrlSetState($lbl_skip_chars, $GUI_SHOW)
			GUICtrlSetState($input_skip_chars, $GUI_SHOW)
			GUICtrlSetData($lbl_delay, "delay")
			GUICtrlSetData($input_delay, 50)
			GUICtrlSetTip($input_delay, "delay between two animation steps (in ms) -> 1 = fast - 1000 - slow" & @LF & "time to wait between two animation steps (in ms)")
			GUICtrlSetState($lbl_delay, $GUI_SHOW)
			GUICtrlSetState($input_delay, $GUI_SHOW)

		Case $s_combo = "Blink"
			GUICtrlSetState($lbl_texts, $GUI_SHOW)
			GUICtrlSetState($input_texts, $GUI_SHOW)
			GUICtrlSetData($lbl_delay, "blink_delay")
			GUICtrlSetData($input_delay, 50)
			GUICtrlSetTip($input_delay, "time to show the text")
			GUICtrlSetState($lbl_delay, $GUI_SHOW)
			GUICtrlSetState($input_delay, $GUI_SHOW)
			GUICtrlSetData($lbl_hide_delay, "hide_delay")
			GUICtrlSetState($lbl_hide_delay, $GUI_SHOW)
			GUICtrlSetData($input_hide_delay, 50)
			GUICtrlSetState($input_hide_delay, $GUI_SHOW)
			GUICtrlSetData($lbl_type, "blink_type")
			GUICtrlSetData($combo_type, "")
			GUICtrlSetData($combo_type, "all|periodic|parts", "all")
			GUICtrlSetState($lbl_type, $GUI_SHOW)
			GUICtrlSetState($combo_type, $GUI_SHOW)
			GUICtrlSetData($lbl_advanced, "advanced")
			GUICtrlSetState($lbl_advanced, $GUI_SHOW)
			GUICtrlSetData($input_advanced, "")
			GUICtrlSetTip($input_advanced, 'at "all" none - at "periodic" step - at "parts" array containing cutting positions or positions in format "1.4.9"')
			GUICtrlSetState($input_advanced, $GUI_SHOW)
			GUICtrlSetData($lbl_repetitions, "repetitions")
			GUICtrlSetState($lbl_repetitions, $GUI_SHOW)
			GUICtrlSetData($input_repetitions, 1)
			GUICtrlSetState($input_repetitions, $GUI_SHOW)
			GUICtrlSetTip($input_repetitions, 'number of repetitions of the effect')

		Case $s_combo = "Broad"
			GUICtrlSetState($lbl_texts, $GUI_SHOW)
			GUICtrlSetState($input_texts, $GUI_SHOW)
			GUICtrlSetData($lbl_delay, "delay")
			GUICtrlSetData($input_delay, 100)
			GUICtrlSetTip($input_delay, "delay between two animation steps (in ms) -> 1 = fast - 1000 - slow" & @LF & "time to wait between two animation steps (in ms)")
			GUICtrlSetData($lbl_start_char, "char")
			GUICtrlSetState($lbl_start_char, $GUI_SHOW)
			GUICtrlSetData($input_start_char, " ")
			GUICtrlSetState($input_start_char, $GUI_SHOW)
			GUICtrlSetTip($input_start_char, "char to insert in order to enlarge text")
			GUICtrlSetData($lbl_type, "go_back")
			GUICtrlSetData($combo_type, "")
			GUICtrlSetData($combo_type, "0|1", "0")
			GUICtrlSetState($lbl_type, $GUI_SHOW)
			GUICtrlSetState($combo_type, $GUI_SHOW)
			GUICtrlSetData($lbl_repetitions, "delay_before_go_back")
			GUICtrlSetState($lbl_repetitions, $GUI_SHOW)
			GUICtrlSetData($input_repetitions, 500)
			GUICtrlSetState($input_repetitions, $GUI_SHOW)
			GUICtrlSetTip($input_repetitions, 'time to wait before smallen the text again')

		Case $s_combo = "Color Sequence" Or $s_combo = "Show text behind char"
			If $s_combo = "Color Sequence" Then
				GUICtrlSetData($input_delay, 50)
				GUICtrlSetData($lbl_start_char, "colors")
				GUICtrlSetData($input_start_char, "black.green.blue.0xffffff")
				GUICtrlSetTip($input_start_char, 'the colors to fade through. Formattad with "." between values')
			ElseIf $s_combo = "Show text behind char" Then
				GUICtrlSetData($input_delay, 100)
				GUICtrlSetData($lbl_start_char, "char")
				GUICtrlSetData($input_start_char, "*")
				GUICtrlSetTip($input_start_char, 'char over the text at the beginning')
			EndIf
			GUICtrlSetState($lbl_start_char, $GUI_SHOW)
			GUICtrlSetState($input_start_char, $GUI_SHOW)
			GUICtrlSetState($lbl_texts, $GUI_SHOW)
			GUICtrlSetState($input_texts, $GUI_SHOW)
			GUICtrlSetData($lbl_delay, "delay")

		Case $s_combo = "Color to color"
			GUICtrlSetState($lbl_texts, $GUI_SHOW)
			GUICtrlSetState($input_texts, $GUI_SHOW)
			GUICtrlSetData($lbl_delay, "duration_per_change")
			GUICtrlSetData($input_delay, 2000)
			GUICtrlSetData($lbl_start_char, "colors")
			GUICtrlSetState($lbl_start_char, $GUI_SHOW)
			GUICtrlSetData($input_start_char, "black.white")
			GUICtrlSetState($input_start_char, $GUI_SHOW)
			GUICtrlSetTip($input_start_char, 'the colors to fade through. Formattad with "." between values')
			GUICtrlSetData($lbl_pause, "precision")
			GUICtrlSetState($lbl_pause, $GUI_SHOW)
			GUICtrlSetData($input_pause, 100)
			GUICtrlSetState($input_pause, $GUI_SHOW)
			GUICtrlSetTip($input_pause, "internal compution steps")

		Case $s_combo = "Enlarge from left" Or $s_combo = "Enlarge from right"
			GUICtrlSetState($lbl_texts, $GUI_SHOW)
			GUICtrlSetState($input_texts, $GUI_SHOW)
			GUICtrlSetData($lbl_delay, "delay")
			GUICtrlSetData($input_delay, 100)
			GUICtrlSetData($lbl_type, "over_old")
			GUICtrlSetData($combo_type, "")
			GUICtrlSetData($combo_type, "0|1", "0")
			GUICtrlSetState($lbl_type, $GUI_SHOW)
			GUICtrlSetState($combo_type, $GUI_SHOW)

		Case $s_combo = "Mix up chars"
			GUICtrlSetState($lbl_texts, $GUI_SHOW)
			GUICtrlSetState($input_texts, $GUI_SHOW)
			GUICtrlSetData($lbl_delay, "delay")
			GUICtrlSetData($input_delay, 50)
			GUICtrlSetData($lbl_showtime, "effect_width")
			GUICtrlSetState($lbl_showtime, $GUI_SHOW)
			GUICtrlSetData($input_showtime, 1)
			GUICtrlSetState($input_showtime, $GUI_SHOW)
			GUICtrlSetTip($input_showtime, "width of the effect")
			GUICtrlSetData($lbl_type, "direction")
			GUICtrlSetData($combo_type, "")
			GUICtrlSetData($combo_type, "to_right|to left", "to_right")
			GUICtrlSetState($lbl_type, $GUI_SHOW)
			GUICtrlSetState($combo_type, $GUI_SHOW)

		Case $s_combo = "Move cap char through text" Or $s_combo = "Move small char through text" Or $s_combo = "Wave"
			GUICtrlSetState($lbl_texts, $GUI_SHOW)
			GUICtrlSetState($input_texts, $GUI_SHOW)
			GUICtrlSetData($lbl_delay, "delay")
			GUICtrlSetData($input_delay, 50)
			GUICtrlSetData($lbl_showtime, "effect_width")
			GUICtrlSetTip($input_showtime, "width of the effect")
			If $s_combo = "Wave" Then
				GUICtrlSetData($input_showtime, 3)
				GUICtrlSetData($lbl_type, "uncover_after_effect")
				GUICtrlSetData($combo_type, "")
				GUICtrlSetData($combo_type, "1|0", "1")
				GUICtrlSetData($lbl_convert_to_small, "direction")
				GUICtrlSetData($combo_convert_to_small, "")
				GUICtrlSetData($combo_convert_to_small, "to_right|to_left", "to_right")
			Else
				GUICtrlSetData($input_showtime, 1)
				GUICtrlSetData($lbl_type, "direction")
				GUICtrlSetData($combo_type, "")
				GUICtrlSetData($combo_type, "to_right|to_left", "to_right")
				If $s_combo = "Move cap char through text" Then GUICtrlSetData($lbl_convert_to_small, "convert_to_small")
				If $s_combo = "Move small char through text" Then GUICtrlSetData($lbl_convert_to_small, "convert_to_caps")
				GUICtrlSetData($combo_convert_to_small, "")
				GUICtrlSetData($combo_convert_to_small, "0|1", "0")
			EndIf
			GUICtrlSetState($lbl_showtime, $GUI_SHOW)
			GUICtrlSetState($input_showtime, $GUI_SHOW)
			GUICtrlSetState($lbl_type, $GUI_SHOW)
			GUICtrlSetState($combo_type, $GUI_SHOW)
			GUICtrlSetState($lbl_convert_to_small, $GUI_SHOW)
			GUICtrlSetState($combo_convert_to_small, $GUI_SHOW)

		Case $s_combo = "Move in from left" Or $s_combo = "Move out to left"
			GUICtrlSetState($lbl_texts, $GUI_SHOW)
			GUICtrlSetState($input_texts, $GUI_SHOW)
			GUICtrlSetData($lbl_delay, "delay")
			GUICtrlSetData($input_delay, 100)

		Case $s_combo = "Move in from right" Or $s_combo = "Move out to right" Or $s_combo = "Uncover from wall to wall"
			If $s_combo = "Uncover from wall to wall" Then
				GUICtrlSetData($lbl_delay, "delay")
				GUICtrlSetData($input_delay, 50)
				GUICtrlSetData($lbl_showtime, "turn_arounds")
				GUICtrlSetData($input_showtime, 1)
				GUICtrlSetTip($input_showtime, 'number of "wall hits"')
			Else
				GUICtrlSetData($lbl_delay, "delay")
				GUICtrlSetData($input_delay, 100)
				GUICtrlSetData($lbl_showtime, "text_min_width")
				GUICtrlSetData($input_showtime, 75)
				GUICtrlSetTip($input_showtime, "minimum text width (text is enlarged automatically if it is shorter)")
			EndIf
			GUICtrlSetState($lbl_showtime, $GUI_SHOW)
			GUICtrlSetState($input_showtime, $GUI_SHOW)
			GUICtrlSetState($lbl_texts, $GUI_SHOW)
			GUICtrlSetState($input_texts, $GUI_SHOW)

		Case $s_combo = "Move string through text"
			GUICtrlSetState($lbl_texts, $GUI_SHOW)
			GUICtrlSetState($input_texts, $GUI_SHOW)
			GUICtrlSetData($lbl_delay, "delay")
			GUICtrlSetData($input_delay, 100)
			GUICtrlSetData($lbl_start_char, "string")
			GUICtrlSetState($lbl_start_char, $GUI_SHOW)
			GUICtrlSetData($input_start_char, "->")
			GUICtrlSetState($input_start_char, $GUI_SHOW)
			GUICtrlSetTip($input_start_char, 'string to move through tex')
			GUICtrlSetData($lbl_type, "show_complete_text")
			GUICtrlSetData($combo_type, "")
			GUICtrlSetData($combo_type, "0|1", "0")
			GUICtrlSetState($lbl_type, $GUI_SHOW)
			GUICtrlSetState($combo_type, $GUI_SHOW)

		Case $s_combo = "Raining" Or $s_combo = "Rainbow"
			GUICtrlSetState($lbl_texts, $GUI_SHOW)
			GUICtrlSetState($input_texts, $GUI_SHOW)
			If $s_combo = "Raining" Then
				GUICtrlSetData($lbl_delay, "delay")
				GUICtrlSetData($input_delay, 50)
				GUICtrlSetData($lbl_showtime, "duration")
				GUICtrlSetData($input_showtime, 3000)
				GUICtrlSetData($lbl_type, "over_old")
			Else
				GUICtrlSetData($lbl_delay, "duration_per_change")
				GUICtrlSetData($input_delay, 2000)
				GUICtrlSetData($lbl_showtime, "precision")
				GUICtrlSetData($input_showtime, 50)
				GUICtrlSetData($lbl_type, "direction")
			EndIf
			GUICtrlSetState($lbl_showtime, $GUI_SHOW)
			GUICtrlSetState($input_showtime, $GUI_SHOW)
			GUICtrlSetTip($input_showtime, "")
			GUICtrlSetData($combo_type, "")
			GUICtrlSetData($combo_type, "0|1", "0")
			GUICtrlSetState($lbl_type, $GUI_SHOW)
			GUICtrlSetState($combo_type, $GUI_SHOW)

		Case $s_combo = "Scroll through options"
			GUICtrlSetData($input_delay, 50)
			GUICtrlSetData($lbl_delay, "delay")
			GUICtrlSetState($lbl_texts, $GUI_SHOW)
			GUICtrlSetState($input_texts, $GUI_SHOW)

		Case $s_combo = "Spin"
			GUICtrlSetState($lbl_texts, $GUI_SHOW)
			GUICtrlSetState($input_texts, $GUI_SHOW)
			GUICtrlSetData($lbl_delay, "delay")
			GUICtrlSetData($input_delay, 100)
			GUICtrlSetData($lbl_showtime, "num_spins")
			GUICtrlSetState($lbl_showtime, $GUI_SHOW)
			GUICtrlSetData($input_showtime, 1)
			GUICtrlSetState($input_showtime, $GUI_SHOW)
			GUICtrlSetTip($input_showtime, "number of spins")
			GUICtrlSetData($lbl_pause, "spin_delay")
			GUICtrlSetState($lbl_pause, $GUI_SHOW)
			GUICtrlSetData($input_pause, 0)
			GUICtrlSetState($input_pause, $GUI_SHOW)
			GUICtrlSetTip($input_pause, "delay between two spins (in ms)")

		Case $s_combo = "Small"
			GUICtrlSetData($lbl_delay, "delay")
			GUICtrlSetData($input_delay, 100)
			GUICtrlSetData($lbl_start_char, "char")
			GUICtrlSetData($input_start_char, " ")
			GUICtrlSetTip($input_start_char, 'char which shall be removed')
			GUICtrlSetState($lbl_start_char, $GUI_SHOW)
			GUICtrlSetState($input_start_char, $GUI_SHOW)

		Case $s_combo = "Spotlight"
			GUICtrlSetState($lbl_texts, $GUI_SHOW)
			GUICtrlSetState($input_texts, $GUI_SHOW)
			GUICtrlSetData($lbl_delay, "delay")
			GUICtrlSetData($input_delay, 50)
			GUICtrlSetData($lbl_repetitions, "effect_width")
			GUICtrlSetState($lbl_repetitions, $GUI_SHOW)
			GUICtrlSetData($input_repetitions, 1)
			GUICtrlSetState($input_repetitions, $GUI_SHOW)
			GUICtrlSetTip($input_repetitions, "width of the effect")
			GUICtrlSetData($lbl_start_char, "highlighting_start_char")
			GUICtrlSetData($input_start_char, "(")
			GUICtrlSetTip($input_start_char, 'char at the beginning of the highlighting')
			GUICtrlSetState($lbl_start_char, $GUI_SHOW)
			GUICtrlSetState($input_start_char, $GUI_SHOW)
			GUICtrlSetData($lbl_highlighting_end_char, "highlighting_end_char")
			GUICtrlSetState($lbl_highlighting_end_char, $GUI_SHOW)
			GUICtrlSetData($input_highlighting_end_char, ")")
			GUICtrlSetState($input_highlighting_end_char, $GUI_SHOW)
			GUICtrlSetTip($input_highlighting_end_char, 'char at the end of the highlighting')
			GUICtrlSetData($lbl_type, "display_type")
			GUICtrlSetData($combo_type, "")
			GUICtrlSetData($combo_type, "2|1|0", "0")
			GUICtrlSetState($lbl_type, $GUI_SHOW)
			GUICtrlSetState($combo_type, $GUI_SHOW)
			GUICtrlSetData($lbl_convert_to_small, "direction")
			GUICtrlSetState($lbl_convert_to_small, $GUI_SHOW)
			GUICtrlSetData($combo_convert_to_small, "")
			GUICtrlSetData($combo_convert_to_small, "to_right|to_left", "to_right")
			GUICtrlSetState($combo_convert_to_small, $GUI_SHOW)
		Case $s_combo = "Style"
			GUICtrlSetState($lbl_texts, $GUI_SHOW)
			GUICtrlSetState($input_texts, $GUI_SHOW)
			GUICtrlSetState($lbl_delay, $GUI_HIDE)
			GUICtrlSetState($input_delay, $GUI_HIDE)
			GUICtrlSetData($lbl_type, "type")
			GUICtrlSetData($combo_type, "")
			GUICtrlSetData($combo_type, "bold|italic|underline", "bold")
			GUICtrlSetState($lbl_type, $GUI_SHOW)
			GUICtrlSetState($combo_type, $GUI_SHOW)
			GUICtrlSetData($lbl_convert_to_small, "remove")
			GUICtrlSetState($lbl_convert_to_small, $GUI_SHOW)
			GUICtrlSetData($combo_convert_to_small, "")
			GUICtrlSetData($combo_convert_to_small, "1|0", "1")
			GUICtrlSetState($combo_convert_to_small, $GUI_SHOW)
			GUICtrlSetData($lbl_showtime, "show_time")
			GUICtrlSetState($lbl_showtime, $GUI_SHOW)
			GUICtrlSetData($input_showtime, 1500)
			GUICtrlSetState($input_showtime, $GUI_SHOW)
			GUICtrlSetTip($input_showtime, "time to show the effect before undoing it")
			GUICtrlSetState($lbl_font, $GUI_SHOW)
			GUICtrlSetState($input_font, $GUI_SHOW)
			GUICtrlSetState($input_font, $GUI_SHOW)
			GUICtrlSetStyle($input_font, $ES_READONLY)
			GUICtrlSetState($btn_font, $GUI_SHOW)
			GUICtrlSetState($btn_font, $GUI_ENABLE)
		Case $s_combo = "Zoom"
			GUICtrlSetState($lbl_texts, $GUI_SHOW)
			GUICtrlSetState($input_texts, $GUI_SHOW)
			GUICtrlSetData($lbl_delay, "delay")
			GUICtrlSetData($input_delay, 50)
			GUICtrlSetData($lbl_hide_delay, "start_size")
			GUICtrlSetState($lbl_hide_delay, $GUI_SHOW)
			GUICtrlSetData($input_hide_delay, 9)
			GUICtrlSetState($input_hide_delay, $GUI_SHOW)
			GUICtrlSetTip($input_hide_delay, "text size at the beginning of the effect")
			GUICtrlSetData($lbl_pause, "end_size")
			GUICtrlSetState($lbl_pause, $GUI_SHOW)
			GUICtrlSetData($input_pause, 2)
			GUICtrlSetState($input_pause, $GUI_SHOW)
			GUICtrlSetTip($input_pause, "text size at the end of the effect")
			GUICtrlSetState($lbl_step, $GUI_SHOW)
			GUICtrlSetState($input_step, $GUI_SHOW)
			GUICtrlSetState($lbl_font, $GUI_SHOW)
			GUICtrlSetState($input_font, $GUI_SHOW)
			GUICtrlSetState($input_font, $GUI_SHOW)
			GUICtrlSetStyle($input_font, $ES_READONLY)
			GUICtrlSetState($btn_font, $GUI_SHOW)
			GUICtrlSetState($btn_font, $GUI_ENABLE)
			GUICtrlSetState($lbl_remove, $GUI_SHOW)
			GUICtrlSetState($combo_remove, $GUI_SHOW)

	EndSelect
	GUICtrlSetData($preview_label, "Preview in Label")
	GUICtrlSetFont($preview_label, -1, -1, -1, "Courier New")
	GUICtrlSetData($preview_input, "Preview in Input")
	GUICtrlSetFont($preview_input, -1, -1, -1, "Courier New")
EndFunc   ;==>_ShowParams

Func _Preview($s_combo)
	Select
		Case $s_combo = "About Messages"
			_txt_eff__about_messages ($gui, $preview_label, $credits, Number(GUICtrlRead($input_delay)), Number(GUICtrlRead($input_showtime)), Number(GUICtrlRead($input_pause)), GUICtrlRead($combo_type))
			_txt_eff__about_messages ($gui, $preview_input, $credits, Number(GUICtrlRead($input_delay)), Number(GUICtrlRead($input_showtime)), Number(GUICtrlRead($input_pause)), GUICtrlRead($combo_type))
		Case $s_combo = "Airport"
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_label)
			EndIf
			_txt_eff__airport ($gui, $preview_label, $s_text, Number(GUICtrlRead($input_delay)), GUICtrlRead($input_start_char), Number(GUICtrlRead($input_skip_chars)))
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_input)
			EndIf
			_txt_eff__airport ($gui, $preview_input, $s_text, Number(GUICtrlRead($input_delay)), GUICtrlRead($input_start_char), Number(GUICtrlRead($input_skip_chars)))
		Case $s_combo = "Blink"
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_label)
			EndIf
			_txt_eff__blink ($gui, $preview_label, $s_text, Number(GUICtrlRead($input_delay)), Number(GUICtrlRead($input_hide_delay)), GUICtrlRead($combo_type), GUICtrlRead($input_advanced), Number(GUICtrlRead($input_repetitions)))
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_input)
			EndIf
			_txt_eff__blink ($gui, $preview_input, $s_text, Number(GUICtrlRead($input_delay)), Number(GUICtrlRead($input_hide_delay)), GUICtrlRead($combo_type), GUICtrlRead($input_advanced), Number(GUICtrlRead($input_repetitions)))
		Case $s_combo = "Broad"
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_label)
			EndIf
			_txt_eff__broad ($gui, $preview_label, $s_text, Number(GUICtrlRead($input_delay)), GUICtrlRead($input_start_char), GUICtrlRead($combo_type), Number(GUICtrlRead($input_repetitions)))
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_input)
			EndIf
			_txt_eff__broad ($gui, $preview_input, $s_text, Number(GUICtrlRead($input_delay)), GUICtrlRead($input_start_char), GUICtrlRead($combo_type), Number(GUICtrlRead($input_repetitions)))
		Case $s_combo = "Color Sequence"
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_label)
			EndIf
			_txt_eff__color_sequence ($gui, $preview_label, $s_text, Number(GUICtrlRead($input_delay)), GUICtrlRead($input_start_char))
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_input)
			EndIf
			_txt_eff__color_sequence ($gui, $preview_input, $s_text, Number(GUICtrlRead($input_delay)), GUICtrlRead($input_start_char))
		Case $s_combo = "Color to color"
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_label)
			EndIf
			_txt_eff__color_to_color ($gui, $preview_label, $s_text, Number(GUICtrlRead($input_delay)), GUICtrlRead($input_start_char), Number(GUICtrlRead($input_pause)))
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_input)
			EndIf
			_txt_eff__color_to_color ($gui, $preview_input, $s_text, Number(GUICtrlRead($input_delay)), GUICtrlRead($input_start_char), Number(GUICtrlRead($input_pause)))
		Case $s_combo = "Enlarge from left"
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_label)
			EndIf
			_txt_eff__enlarge_from_left ($gui, $preview_label, $s_text, Number(GUICtrlRead($input_delay)), GUICtrlRead($combo_type))
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_input)
			EndIf
			_txt_eff__enlarge_from_left ($gui, $preview_input, $s_text, Number(GUICtrlRead($input_delay)), GUICtrlRead($combo_type))
		Case $s_combo = "Enlarge from right"
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_label)
			EndIf
			_txt_eff__enlarge_from_right ($gui, $preview_label, $s_text, Number(GUICtrlRead($input_delay)), GUICtrlRead($combo_type))
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_input)
			EndIf
			_txt_eff__enlarge_from_right ($gui, $preview_input, $s_text, Number(GUICtrlRead($input_delay)), GUICtrlRead($combo_type))
		Case $s_combo = "Mix up chars"
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_label)
			EndIf
			_txt_eff__mix_up_chars ($gui, $preview_label, $s_text, Number(GUICtrlRead($input_delay)), Number(GUICtrlRead($input_showtime)), GUICtrlRead($combo_type))
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_input)
			EndIf
			_txt_eff__mix_up_chars ($gui, $preview_input, $s_text, Number(GUICtrlRead($input_delay)), Number(GUICtrlRead($input_showtime)), GUICtrlRead($combo_type))
		Case $s_combo = "Move cap char through text"
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_label)
			EndIf
			_txt_eff__move_cap_char_through_text ($gui, $preview_label, $s_text, Number(GUICtrlRead($input_delay)), Number(GUICtrlRead($input_showtime)), GUICtrlRead($combo_type), GUICtrlRead($combo_convert_to_small))
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_input)
			EndIf
			_txt_eff__move_cap_char_through_text ($gui, $preview_input, $s_text, Number(GUICtrlRead($input_delay)), Number(GUICtrlRead($input_showtime)), GUICtrlRead($combo_type), GUICtrlRead($combo_convert_to_small))
		Case $s_combo = "Move small char through text"
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_label)
			EndIf
			_txt_eff__move_small_char_through_text ($gui, $preview_label, $s_text, Number(GUICtrlRead($input_delay)), Number(GUICtrlRead($input_showtime)), GUICtrlRead($combo_type), GUICtrlRead($combo_convert_to_small))
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_input)
			EndIf
			_txt_eff__move_small_char_through_text ($gui, $preview_input, $s_text, Number(GUICtrlRead($input_delay)), Number(GUICtrlRead($input_showtime)), GUICtrlRead($combo_type), GUICtrlRead($combo_convert_to_small))
		Case $s_combo = "Move in from left"
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_label)
			EndIf
			_txt_eff__move_in_from_left ($gui, $preview_label, $s_text, Number(GUICtrlRead($input_delay)))
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_input)
			EndIf
			_txt_eff__move_in_from_left ($gui, $preview_input, $s_text, Number(GUICtrlRead($input_delay)))
		Case $s_combo = "Move out to left"
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_label)
			EndIf
			_txt_eff__move_out_to_left ($gui, $preview_label, $s_text, Number(GUICtrlRead($input_delay)))
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_input)
			EndIf
			_txt_eff__move_out_to_left ($gui, $preview_input, $s_text, Number(GUICtrlRead($input_delay)))
		Case $s_combo = "Move in from right"
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_label)
			EndIf
			_txt_eff__move_in_from_right ($gui, $preview_label, $s_text, Number(GUICtrlRead($input_delay)), Number(GUICtrlRead($input_showtime)))
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_input)
			EndIf
			_txt_eff__move_in_from_right ($gui, $preview_input, $s_text, Number(GUICtrlRead($input_delay)), Number(GUICtrlRead($input_showtime)))
		Case $s_combo = "Move out to right"
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_label)
			EndIf
			_txt_eff__move_out_to_right ($gui, $preview_label, $s_text, Number(GUICtrlRead($input_delay)), Number(GUICtrlRead($input_showtime)))
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_input)
			EndIf
			_txt_eff__move_out_to_right ($gui, $preview_input, $s_text, Number(GUICtrlRead($input_delay)), Number(GUICtrlRead($input_showtime)))
		Case $s_combo = "Move string through text"
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_label)
			EndIf
			_txt_eff__move_string_through_text ($gui, $preview_label, $s_text, Number(GUICtrlRead($input_delay)), GUICtrlRead($input_start_char), GUICtrlRead($combo_type))
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_input)
			EndIf
			_txt_eff__move_string_through_text ($gui, $preview_input, $s_text, Number(GUICtrlRead($input_delay)), GUICtrlRead($input_start_char), GUICtrlRead($combo_type))
		Case $s_combo = "Raining"
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_label)
			EndIf
			_txt_eff__raining ($gui, $preview_label, $s_text, Number(GUICtrlRead($input_delay)), Number(GUICtrlRead($input_showtime)), GUICtrlRead($combo_type))
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_input)
			EndIf
			_txt_eff__raining ($gui, $preview_input, $s_text, Number(GUICtrlRead($input_delay)), Number(GUICtrlRead($input_showtime)), GUICtrlRead($combo_type))
		Case $s_combo = "Rainbow"
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_label)
			EndIf
			_txt_eff__rainbow ($gui, $preview_label, $s_text, Number(GUICtrlRead($input_delay)), Number(GUICtrlRead($input_showtime)), GUICtrlRead($combo_type))
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_input)
			EndIf
			_txt_eff__rainbow ($gui, $preview_input, $s_text, Number(GUICtrlRead($input_delay)), Number(GUICtrlRead($input_showtime)), GUICtrlRead($combo_type))
		Case $s_combo = "Show text behind char"
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_label)
			EndIf
			_txt_eff__show_text_behind_char ($gui, $preview_label, $s_text, Number(GUICtrlRead($input_delay)), GUICtrlRead($input_start_char))
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_input)
			EndIf
			_txt_eff__show_text_behind_char ($gui, $preview_input, $s_text, Number(GUICtrlRead($input_delay)), GUICtrlRead($input_start_char))
		Case $s_combo = "Scroll through options"
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_label)
			EndIf
			_txt_eff__scroll_through_options ($gui, $preview_label, $options, $s_text, Number(GUICtrlRead($input_delay)))
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_input)
			EndIf
			_txt_eff__scroll_through_options ($gui, $preview_input, $options, $s_text, Number(GUICtrlRead($input_delay)))
		Case $s_combo = "Spin"
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_label)
			EndIf
			_txt_eff__spin ($gui, $preview_label, $s_text, Number(GUICtrlRead($input_delay)), Number(GUICtrlRead($input_showtime)), Number(GUICtrlRead($input_pause)))
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_input)
			EndIf
			_txt_eff__spin ($gui, $preview_input, $s_text, Number(GUICtrlRead($input_delay)), Number(GUICtrlRead($input_showtime)), Number(GUICtrlRead($input_pause)))
		Case $s_combo = "Small"
			_txt_eff__small ($gui, $preview_label, Number(GUICtrlRead($input_delay)), GUICtrlRead($input_start_char))
			_txt_eff__small ($gui, $preview_input, Number(GUICtrlRead($input_delay)), GUICtrlRead($input_start_char))
		Case $s_combo = "Spotlight"
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_label)
			EndIf
			_txt_eff__spotlight ($gui, $preview_label, $s_text, Number(GUICtrlRead($input_delay)), Number(GUICtrlRead($input_repetitions)), GUICtrlRead($input_start_char), GUICtrlRead($input_highlighting_end_char), Number(GUICtrlRead($combo_type)), GUICtrlRead($combo_convert_to_small))
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_input)
			EndIf
			_txt_eff__spotlight ($gui, $preview_input, $s_text, Number(GUICtrlRead($input_delay)), Number(GUICtrlRead($input_repetitions)), GUICtrlRead($input_start_char), GUICtrlRead($input_highlighting_end_char), Number(GUICtrlRead($combo_type)), GUICtrlRead($combo_convert_to_small))
		Case $s_combo = "Style"
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_label)
			EndIf
			_txt_eff__style ($gui, $preview_label, $s_text, GUICtrlRead($combo_type), GUICtrlRead($input_font), Number(GUICtrlRead($combo_convert_to_small)), Number(GUICtrlRead($input_showtime)))
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_input)
			EndIf
			_txt_eff__style ($gui, $preview_input, $s_text, GUICtrlRead($combo_type), GUICtrlRead($input_font), Number(GUICtrlRead($combo_convert_to_small)), Number(GUICtrlRead($input_showtime)))
		Case $s_combo = "Uncover from wall to wall"
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_label)
			EndIf
			_txt_eff__uncover_from_wall_to_wall ($gui, $preview_label, $s_text, GUICtrlRead($input_delay), Number(GUICtrlRead($input_showtime)))
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_input)
			EndIf
			_txt_eff__uncover_from_wall_to_wall ($gui, $preview_input, $s_text, GUICtrlRead($input_delay), Number(GUICtrlRead($input_showtime)))
		Case $s_combo = "Wave"
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_label)
			EndIf
			_txt_eff__wave ($gui, $preview_label, $s_text, Number(GUICtrlRead($input_delay)), Number(GUICtrlRead($input_showtime)), Number(GUICtrlRead($combo_type)), GUICtrlRead($combo_convert_to_small))
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_input)
			EndIf
			_txt_eff__wave ($gui, $preview_input, $s_text, Number(GUICtrlRead($input_delay)), Number(GUICtrlRead($input_showtime)), Number(GUICtrlRead($combo_type)), GUICtrlRead($combo_convert_to_small))
		Case $s_combo = "Zoom"
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_label)
			EndIf
			_txt_eff__zoom ($gui, $preview_label, $s_text, Number(GUICtrlRead($input_delay)), Number(GUICtrlRead($input_hide_delay)), Number(GUICtrlRead($input_pause)), Number(GUICtrlRead($input_step)), GUICtrlRead($input_font), Number(GUICtrlRead($combo_remove)))
			If StringLen(GUICtrlRead($input_texts)) > 0 Then
				$s_text = GUICtrlRead($input_texts)
			Else
				$s_text = GUICtrlRead($preview_input)
			EndIf
			_txt_eff__zoom ($gui, $preview_input, $s_text, Number(GUICtrlRead($input_delay)), Number(GUICtrlRead($input_hide_delay)), Number(GUICtrlRead($input_pause)), Number(GUICtrlRead($input_step)), GUICtrlRead($input_font), Number(GUICtrlRead($combo_remove)))
	EndSelect
EndFunc   ;==>_Preview

Func _BuildFunction($s_combo)
	Local $s_func
	Select
		Case $s_combo = "About Messages"
			$s_func = "_txt_eff__about_messages ("
			If StringLen(GUICtrlRead($input_winhandle)) == 0 Then
				$s_func = $s_func & '"window handle", '
			Else
				$s_func = $s_func & GUICtrlRead($input_winhandle) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_control_id)) == 0 Then
				$s_func = $s_func & '"control id", '
			Else
				$s_func = $s_func & GUICtrlRead($input_control_id) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_texts)) == 0 Then
				$s_func = $s_func & '"", '
			Else
				$s_func = $s_func & GUICtrlRead($input_texts) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_delay)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_delay)) & ", "
			Else
				$s_func = $s_func & "default, "
			EndIf
			If StringLen(GUICtrlRead($input_showtime)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_showtime)) & ", "
			Else
				$s_func = $s_func & "default, "
			EndIf
			If StringLen(GUICtrlRead($input_pause)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_pause)) & ", "
			Else
				$s_func = $s_func & "default, "
			EndIf
			$s_func = $s_func & '"' & GUICtrlRead($combo_type) & '")'
		Case $s_combo = "Airport"
			$s_func = "_txt_eff__airport ("
			If StringLen(GUICtrlRead($input_winhandle)) == 0 Then
				$s_func = $s_func & '"window handle", '
			Else
				$s_func = $s_func & GUICtrlRead($input_winhandle) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_control_id)) == 0 Then
				$s_func = $s_func & '"control id", '
			Else
				$s_func = $s_func & GUICtrlRead($input_control_id) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_texts)) == 0 Then
				$s_func = $s_func & '"", '
			Else
				$s_func = $s_func & GUICtrlRead($input_texts) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_delay)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_delay)) & ", "
			Else
				$s_func = $s_func & "default, "
			EndIf
			If StringLen(GUICtrlRead($input_start_char)) > 0 Then
				$s_func = $s_func & GUICtrlRead($input_start_char) & ", "
			Else
				$s_func = $s_func & "default, "
			EndIf
			If StringLen(GUICtrlRead($input_skip_chars)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_skip_chars)) & ")"
			Else
				$s_func = $s_func & "default)"
			EndIf
		Case $s_combo = "Blink"
			$s_func = "_txt_eff__blink ("
			If StringLen(GUICtrlRead($input_winhandle)) == 0 Then
				$s_func = $s_func & '"window handle", '
			Else
				$s_func = $s_func & GUICtrlRead($input_winhandle) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_control_id)) == 0 Then
				$s_func = $s_func & '"control id", '
			Else
				$s_func = $s_func & GUICtrlRead($input_control_id) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_texts)) == 0 Then
				$s_func = $s_func & '"", '
			Else
				$s_func = $s_func & GUICtrlRead($input_texts) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_delay)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_delay)) & ", "
			Else
				$s_func = $s_func & "default, "
			EndIf
			If StringLen(GUICtrlRead($input_hide_delay)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_hide_delay)) & ", "
			Else
				$s_func = $s_func & "default, "
			EndIf
			$s_func = $s_func & '"' & GUICtrlRead($combo_type) & '", '
			If StringLen(GUICtrlRead($input_advanced)) > 0 Then
				$s_func = $s_func & '"' & GUICtrlRead($input_advanced) & '", '
			Else
				$s_func = $s_func & "default, "
			EndIf
			If StringLen(GUICtrlRead($input_repetitions)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_repetitions)) & ")"
			Else
				$s_func = $s_func & "default)"
			EndIf
		Case $s_combo = "Broad"
			$s_func = "_txt_eff__broad ("
			If StringLen(GUICtrlRead($input_winhandle)) == 0 Then
				$s_func = $s_func & '"window handle", '
			Else
				$s_func = $s_func & GUICtrlRead($input_winhandle) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_control_id)) == 0 Then
				$s_func = $s_func & '"control id", '
			Else
				$s_func = $s_func & GUICtrlRead($input_control_id) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_texts)) == 0 Then
				$s_func = $s_func & '"", '
			Else
				$s_func = $s_func & GUICtrlRead($input_texts) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_delay)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_delay)) & ", "
			Else
				$s_func = $s_func & "default, "
			EndIf
			If StringLen(GUICtrlRead($input_start_char)) > 0 And GUICtrlRead($input_start_char) <> " " Then
				$s_func = $s_func & '"' & GUICtrlRead($input_start_char) & '", '
			Else
				$s_func = $s_func & "default, "
			EndIf
			$s_func = $s_func & GUICtrlRead($combo_type) & ', '
			If StringLen(GUICtrlRead($input_repetitions)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_repetitions)) & ")"
			Else
				$s_func = $s_func & "default)"
			EndIf
		Case $s_combo = "Color Sequence" Or $s_combo = "Show text behind char"
			If $s_combo = "Color Sequence" Then $s_func = "_txt_eff__color_sequence ("
			If $s_combo = "Show text behind char" Then $s_func = "_txt_eff__show_text_behind_char ("
			If StringLen(GUICtrlRead($input_winhandle)) == 0 Then
				$s_func = $s_func & '"window handle", '
			Else
				$s_func = $s_func & GUICtrlRead($input_winhandle) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_control_id)) == 0 Then
				$s_func = $s_func & '"control id", '
			Else
				$s_func = $s_func & GUICtrlRead($input_control_id) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_texts)) == 0 Then
				$s_func = $s_func & '"", '
			Else
				$s_func = $s_func & GUICtrlRead($input_texts) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_delay)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_delay)) & ", "
			Else
				$s_func = $s_func & "default, "
			EndIf
			If StringLen(GUICtrlRead($input_start_char)) > 0 And GUICtrlRead($input_start_char) <> " " Then
				$s_func = $s_func & '"' & GUICtrlRead($input_start_char) & '")'
			Else
				$s_func = $s_func & "default)"
			EndIf

		Case $s_combo = "Color to color"
			$s_func = "_txt_eff__color_to_color ("
			If StringLen(GUICtrlRead($input_winhandle)) == 0 Then
				$s_func = $s_func & '"window handle", '
			Else
				$s_func = $s_func & GUICtrlRead($input_winhandle) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_control_id)) == 0 Then
				$s_func = $s_func & '"control id", '
			Else
				$s_func = $s_func & GUICtrlRead($input_control_id) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_texts)) == 0 Then
				$s_func = $s_func & '"", '
			Else
				$s_func = $s_func & GUICtrlRead($input_texts) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_delay)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_delay)) & ", "
			Else
				$s_func = $s_func & "default, "
			EndIf
			If StringLen(GUICtrlRead($input_start_char)) > 0 And GUICtrlRead($input_start_char) <> " " Then
				$s_func = $s_func & '"' & GUICtrlRead($input_start_char) & '", '
			Else
				$s_func = $s_func & "default, "
			EndIf
			If StringLen(GUICtrlRead($input_pause)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_pause)) & ")"
			Else
				$s_func = $s_func & "default)"
			EndIf
		Case $s_combo = "Enlarge from left" Or $s_combo = "Enlarge from right"
			If $s_combo = "Enlarge from left" Then $s_func = "_txt_eff__enlarge_from_left ("
			If $s_combo = "Enlarge from right" Then $s_func = "_txt_eff__enlarge_from_right ("
			If StringLen(GUICtrlRead($input_winhandle)) == 0 Then
				$s_func = $s_func & '"window handle", '
			Else
				$s_func = $s_func & GUICtrlRead($input_winhandle) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_control_id)) == 0 Then
				$s_func = $s_func & '"control id", '
			Else
				$s_func = $s_func & GUICtrlRead($input_control_id) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_texts)) == 0 Then
				$s_func = $s_func & '"", '
			Else
				$s_func = $s_func & GUICtrlRead($input_texts) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_delay)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_delay)) & ", "
			Else
				$s_func = $s_func & "default, "
			EndIf
			$s_func = $s_func & GUICtrlRead($combo_type) & ')'
		Case $s_combo = "Mix up chars"
			$s_func = "_txt_eff__mix_up_chars ("
			If StringLen(GUICtrlRead($input_winhandle)) == 0 Then
				$s_func = $s_func & '"window handle", '
			Else
				$s_func = $s_func & GUICtrlRead($input_winhandle) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_control_id)) == 0 Then
				$s_func = $s_func & '"control id", '
			Else
				$s_func = $s_func & GUICtrlRead($input_control_id) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_texts)) == 0 Then
				$s_func = $s_func & '"", '
			Else
				$s_func = $s_func & GUICtrlRead($input_texts) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_delay)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_delay)) & ", "
			Else
				$s_func = $s_func & "default, "
			EndIf
			If StringLen(GUICtrlRead($input_showtime)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_showtime)) & ", "
			Else
				$s_func = $s_func & "default, "
			EndIf
			$s_func = $s_func & '"' & GUICtrlRead($combo_type) & '")'
		Case $s_combo = "Move cap char through text" Or $s_combo = "Move small char through text" Or $s_combo = "Wave"
			If $s_combo = "Move cap char through text" Then $s_func = "_txt_eff__move_cap_char_through_text ("
			If $s_combo = "Move small char through text" Then $s_func = "_txt_eff__move_small_char_through_text ("
			If $s_combo = "Wave" Then $s_func = "_txt_eff__wave ("
			If StringLen(GUICtrlRead($input_winhandle)) == 0 Then
				$s_func = $s_func & '"window handle", '
			Else
				$s_func = $s_func & GUICtrlRead($input_winhandle) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_control_id)) == 0 Then
				$s_func = $s_func & '"control id", '
			Else
				$s_func = $s_func & GUICtrlRead($input_control_id) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_texts)) == 0 Then
				$s_func = $s_func & '"", '
			Else
				$s_func = $s_func & GUICtrlRead($input_texts) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_delay)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_delay)) & ", "
			Else
				$s_func = $s_func & "default, "
			EndIf
			If StringLen(GUICtrlRead($input_showtime)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_showtime)) & ", "
			Else
				$s_func = $s_func & "default, "
			EndIf
			If $s_combo = "Wave" Then
				If StringLen(GUICtrlRead($combo_type)) > 0 Then
					$s_func = $s_func & Number(GUICtrlRead($combo_type)) & ", "
				Else
					$s_func = $s_func & "default, "
				EndIf
			Else
				$s_func = $s_func & '"' & GUICtrlRead($combo_type) & '", '
			EndIf
			If StringLen(GUICtrlRead($combo_convert_to_small)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($combo_convert_to_small)) & ")"
			Else
				$s_func = $s_func & "default)"
			EndIf

		Case $s_combo = "Move in from left" Or $s_combo = "Move out to left"
			If $s_combo = "Move in from left" Then $s_func = "_txt_eff__move_in_from_left ("
			If $s_combo = "Move out to left" Then $s_func = "_txt_eff__move_out_to_left ("
			If StringLen(GUICtrlRead($input_winhandle)) == 0 Then
				$s_func = $s_func & '"window handle", '
			Else
				$s_func = $s_func & GUICtrlRead($input_winhandle) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_control_id)) == 0 Then
				$s_func = $s_func & '"control id", '
			Else
				$s_func = $s_func & GUICtrlRead($input_control_id) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_texts)) == 0 Then
				$s_func = $s_func & '"", '
			Else
				$s_func = $s_func & GUICtrlRead($input_texts) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_delay)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_delay)) & ")"
			Else
				$s_func = $s_func & "default)"
			EndIf
		Case $s_combo = "Move in from right" Or $s_combo = "Move out to right" Or $s_combo = "Uncover from wall to wall"
			If $s_combo = "Move in from right" Then $s_func = "_txt_eff__move_in_from_right ("
			If $s_combo = "Move out to right" Then $s_func = "_txt_eff__move_out_to_right ("
			If $s_combo = "Uncover from wall to wall" Then $s_func = "_txt_eff__uncover_from_wall_to_wall ("
			If StringLen(GUICtrlRead($input_winhandle)) == 0 Then
				$s_func = $s_func & '"window handle", '
			Else
				$s_func = $s_func & GUICtrlRead($input_winhandle) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_control_id)) == 0 Then
				$s_func = $s_func & '"control id", '
			Else
				$s_func = $s_func & GUICtrlRead($input_control_id) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_texts)) == 0 Then
				$s_func = $s_func & '"", '
			Else
				$s_func = $s_func & GUICtrlRead($input_texts) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_delay)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_delay)) & ", "
			Else
				$s_func = $s_func & "default, "
			EndIf
			If StringLen(GUICtrlRead($input_showtime)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_showtime)) & ")"
			Else
				$s_func = $s_func & "default)"
			EndIf
		Case $s_combo = "Move string through text"
			$s_func = "_txt_eff__move_string_through_text ("
			If StringLen(GUICtrlRead($input_winhandle)) == 0 Then
				$s_func = $s_func & '"window handle", '
			Else
				$s_func = $s_func & GUICtrlRead($input_winhandle) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_control_id)) == 0 Then
				$s_func = $s_func & '"control id", '
			Else
				$s_func = $s_func & GUICtrlRead($input_control_id) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_texts)) == 0 Then
				$s_func = $s_func & '"", '
			Else
				$s_func = $s_func & GUICtrlRead($input_texts) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_delay)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_delay)) & ", "
			Else
				$s_func = $s_func & "default, "
			EndIf
			If StringLen(GUICtrlRead($input_start_char)) > 0 And GUICtrlRead($input_start_char) <> " " Then
				$s_func = $s_func & '"' & GUICtrlRead($input_start_char) & '", '
			Else
				$s_func = $s_func & "default, "
			EndIf
			$s_func = $s_func & GUICtrlRead($combo_type) & ')'

		Case $s_combo = "Raining" Or $s_combo = "Rainbow"
			If $s_combo = "Raining" Then $s_func = "_txt_eff__raining ("
			If $s_combo = "Rainbow" Then $s_func = "_txt_eff__rainbow ("
			If StringLen(GUICtrlRead($input_winhandle)) == 0 Then
				$s_func = $s_func & '"window handle", '
			Else
				$s_func = $s_func & GUICtrlRead($input_winhandle) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_control_id)) == 0 Then
				$s_func = $s_func & '"control id", '
			Else
				$s_func = $s_func & GUICtrlRead($input_control_id) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_texts)) == 0 Then
				$s_func = $s_func & '"", '
			Else
				$s_func = $s_func & GUICtrlRead($input_texts) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_delay)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_delay)) & ", "
			Else
				$s_func = $s_func & "default, "
			EndIf
			If StringLen(GUICtrlRead($input_showtime)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_showtime)) & ', '
			Else
				$s_func = $s_func & "default, "
			EndIf
			$s_func = $s_func & GUICtrlRead($combo_type) & ')'

		Case $s_combo = "Scroll through options"
			$s_func = "_txt_eff__scroll_through_options ("
			If StringLen(GUICtrlRead($input_winhandle)) == 0 Then
				$s_func = $s_func & '"window handle", '
			Else
				$s_func = $s_func & GUICtrlRead($input_winhandle) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_control_id)) == 0 Then
				$s_func = $s_func & '"control id", '
			Else
				$s_func = $s_func & GUICtrlRead($input_control_id) & ", "
			EndIf
			$s_func = $s_func & '$options, '
			If StringLen(GUICtrlRead($input_texts)) == 0 Then
				$s_func = $s_func & '"", '
			Else
				$s_func = $s_func & GUICtrlRead($input_texts) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_delay)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_delay)) & ")"
			Else
				$s_func = $s_func & "default)"
			EndIf
		Case $s_combo = "Spin"
			$s_func = "_txt_eff__spin ("
			If StringLen(GUICtrlRead($input_winhandle)) == 0 Then
				$s_func = $s_func & '"window handle", '
			Else
				$s_func = $s_func & GUICtrlRead($input_winhandle) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_control_id)) == 0 Then
				$s_func = $s_func & '"control id", '
			Else
				$s_func = $s_func & GUICtrlRead($input_control_id) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_texts)) == 0 Then
				$s_func = $s_func & '"", '
			Else
				$s_func = $s_func & GUICtrlRead($input_texts) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_delay)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_delay)) & ", "
			Else
				$s_func = $s_func & "default, "
			EndIf
			If StringLen(GUICtrlRead($input_showtime)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_showtime)) & ", "
			Else
				$s_func = $s_func & "default, "
			EndIf
			If StringLen(GUICtrlRead($input_pause)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_pause)) & ")"
			Else
				$s_func = $s_func & "default)"
			EndIf
		Case $s_combo = "Small"
			$s_func = "_txt_eff__small ("
			If StringLen(GUICtrlRead($input_winhandle)) == 0 Then
				$s_func = $s_func & '"window handle", '
			Else
				$s_func = $s_func & GUICtrlRead($input_winhandle) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_control_id)) == 0 Then
				$s_func = $s_func & '"control id", '
			Else
				$s_func = $s_func & GUICtrlRead($input_control_id) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_delay)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_delay)) & ", "
			Else
				$s_func = $s_func & "default, "
			EndIf
			If StringLen(GUICtrlRead($input_start_char)) > 0 And GUICtrlRead($input_start_char) <> " " Then
				$s_func = $s_func & '"' & GUICtrlRead($input_start_char) & '")'
			Else
				$s_func = $s_func & "default)"
			EndIf

		Case $s_combo = "Spotlight"
			$s_func = "_txt_eff__spotlight ("
			If StringLen(GUICtrlRead($input_winhandle)) == 0 Then
				$s_func = $s_func & '"window handle", '
			Else
				$s_func = $s_func & GUICtrlRead($input_winhandle) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_control_id)) == 0 Then
				$s_func = $s_func & '"control id", '
			Else
				$s_func = $s_func & GUICtrlRead($input_control_id) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_delay)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_delay)) & ", "
			Else
				$s_func = $s_func & "default, "
			EndIf
			If StringLen(GUICtrlRead($input_repetitions)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_repetitions)) & ", "
			Else
				$s_func = $s_func & "default, "
			EndIf
			If StringLen(GUICtrlRead($input_start_char)) > 0 And GUICtrlRead($input_start_char) <> " " Then
				$s_func = $s_func & '"' & GUICtrlRead($input_start_char) & '", '
			Else
				$s_func = $s_func & "default, "
			EndIf
			If StringLen(GUICtrlRead($input_highlighting_end_char)) > 0 Then
				$s_func = $s_func & '"' & GUICtrlRead($input_highlighting_end_char) & '", '
			Else
				$s_func = $s_func & "default, "
			EndIf
			If StringLen(GUICtrlRead($combo_type)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($combo_type)) & ", "
			Else
				$s_func = $s_func & "default, "
			EndIf
			If StringLen(GUICtrlRead($combo_convert_to_small)) > 0 Then
				$s_func = $s_func & '"' & GUICtrlRead($combo_convert_to_small) & '")'
			Else
				$s_func = $s_func & "default)"
			EndIf
		Case $s_combo = "Style"
			$s_func = "_txt_eff__style ("
			If StringLen(GUICtrlRead($input_winhandle)) == 0 Then
				$s_func = $s_func & '"window handle", '
			Else
				$s_func = $s_func & GUICtrlRead($input_winhandle) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_control_id)) == 0 Then
				$s_func = $s_func & '"control id", '
			Else
				$s_func = $s_func & GUICtrlRead($input_control_id) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_texts)) == 0 Then
				$s_func = $s_func & '"", '
			Else
				$s_func = $s_func & GUICtrlRead($input_texts) & ", "
			EndIf
			$s_func = $s_func & '"' & GUICtrlRead($combo_type) & '", "' & GUICtrlRead($input_font) & '", '
			If StringLen(GUICtrlRead($combo_convert_to_small)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($combo_convert_to_small)) & ", "
			Else
				$s_func = $s_func & "default, "
			EndIf
			If StringLen(GUICtrlRead($input_showtime)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_showtime)) & ")"
			Else
				$s_func = $s_func & "default)"
			EndIf
		Case $s_combo = "Zoom"
			$s_func = "_txt_eff__zoom ("
			If StringLen(GUICtrlRead($input_winhandle)) == 0 Then
				$s_func = $s_func & '"window handle", '
			Else
				$s_func = $s_func & GUICtrlRead($input_winhandle) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_control_id)) == 0 Then
				$s_func = $s_func & '"control id", '
			Else
				$s_func = $s_func & GUICtrlRead($input_control_id) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_texts)) == 0 Then
				$s_func = $s_func & '"", '
			Else
				$s_func = $s_func & GUICtrlRead($input_texts) & ", "
			EndIf
			If StringLen(GUICtrlRead($input_delay)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_delay)) & ", "
			Else
				$s_func = $s_func & "default, "
			EndIf
			If StringLen(GUICtrlRead($input_hide_delay)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_hide_delay)) & ", "
			Else
				$s_func = $s_func & "default, "
			EndIf
			If StringLen(GUICtrlRead($input_pause)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_pause)) & ", "
			Else
				$s_func = $s_func & "default, "
			EndIf
			If StringLen(GUICtrlRead($input_step)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($input_step)) & ", "
			Else
				$s_func = $s_func & "default, "
			EndIf
			$s_func = $s_func & '"' & GUICtrlRead($input_font) & '", '
			If StringLen(GUICtrlRead($combo_remove)) > 0 Then
				$s_func = $s_func & Number(GUICtrlRead($combo_remove)) & ")"
			Else
				$s_func = $s_func & "default)"
			EndIf
	EndSelect
	Return $s_func
EndFunc   ;==>_BuildFunction

Func _SendCode($sOutType, $S_TEMPLATE)
	If $sOutType = "Console" Then
		ConsoleWrite(StringReplace($S_TEMPLATE, @CRLF, @LF))
		Exit
	Else
		ClipPut($S_TEMPLATE)
	EndIf
EndFunc   ;==>_SendCode
